@@ -13,6 +13,7 @@ from foundry.game.level.LevelRef import LevelRef
 from foundry.gui.ContextMenu import ContextMenu
 from foundry.gui.JumpCreator import JumpCreator
 from foundry.gui.JumpList import JumpList
+from foundry.gui.LevelSelector import select_by_world_and_level
 from foundry.gui.LevelSizeBar import LevelSizeBar
 from foundry.gui.LevelView import LevelView
 from foundry.gui.ObjectDropdown import ObjectDropdown
@@ -133,7 +134,6 @@ class LevelManager:
         level_ref.data_changed.connect(update_enemy_size_bar)
 
         self.parent.side_palette = PaletteEditor(self.parent)
-        self.parent.side_palette.palette_updated.connect(lambda *_: print("changed"))
         self.parent.side_palette.palette_updated.connect(
             lambda *_: self.controller.on_level_data_changed() if self.controller is not None else None
         )
@@ -167,7 +167,9 @@ class LevelManager:
         def set_object_viewer(item):
             self.parent.object_toolbar_viewer.icon = ObjectIcon(self.parent.object_toolbar_viewer, item)
 
+        self.parent.object_dropdown.object_selected.connect(set_object_viewer)
         self.parent.object_toolbar.selected.connect(set_object_viewer)
+        self.parent.object_toolbar.selected.connect(self.parent.object_dropdown.select_object)
 
         create_toolbar(self.parent, "Object Viewer", [self.parent.object_toolbar_viewer], Qt.LeftToolBarArea)
         create_toolbar(self.parent, "Object Toolbar", [self.parent.object_toolbar], Qt.LeftToolBarArea)
@@ -225,6 +227,16 @@ class LevelManager:
     def update(self, controller: LevelController):
         controller.update()
 
+    @require_enabled
+    def force_select(self, world: int, level: int, *, controller: LevelController):
+        selection = select_by_world_and_level(world, level)
+        controller.update_level(
+            selection.display_information.name if selection.display_information.name is not None else "",
+            selection.generator_pointer - 9,
+            selection.enemy_pointer,
+            selection.tileset,
+        )
+
     @require_enabled
     def on_select(self, controller: LevelController):
         return controller.on_select()
